@@ -906,9 +906,9 @@ class VTGraph(object):
         new_node.add_attributes(node_data["attributes"])
       expansion_nodes.append(new_node)
 
-    if has_more:
-      cursor = data["meta"]["cursor"]
-      next_max = max_nodes_per_relationship - len(data["data"])
+    cursor = has_more.get("cursor")
+    if cursor:
+      next_max = max_nodes_per_relationship - len(new_nodes)
       if next_max > 0:
         return self._get_expansion_nodes(
             node, expansion, max_nodes_per_relationship=next_max,
@@ -1490,10 +1490,19 @@ class VTGraph(object):
         node, expansion, max_nodes_per_relationship)
     # Adds data to graph.
     for node in expansion_nodes:
-      self.add_node(
-          node.node_id, node.node_type, fetch_information=False,
-          node_attributes=node.attributes)
-      self.add_link(node_id, node.node_id, expansion)
+      if node.node_id != node_id:
+        self.add_node(
+            node.node_id, node.node_type, fetch_information=False,
+            node_attributes=node.attributes)
+        self.add_link(node_id, node.node_id, expansion)
+      else:
+        self._log(
+            "Ignored expansion result: {node_id} for expansion type:"
+            "{expansion}. Source and target are the same node."
+              .format(
+                node_id=node.node_id, expansion=expansion),
+            logging.INFO
+        )
     return expansion_nodes
 
   def expand_one_level(self, node_id, max_nodes_per_relationship=40):
